caellion-python-commons: caellion.pycommons.stringutil.formatters Namespace Reference

caellion-python-commons

Classes
caellion.pycommons.stringutil.formatters Namespace Reference

This module provides various string formatters. More...

## Classes
class | InvalidDurationException
| This exception is raised whenever provided duration is zero or negative. More...
class | NumberFormatting
| This class provides various number formats. More...

## Detailed Description

This module provides various string formatters.